import { Col, DatePicker, Form, Input, Radio, Row, Select } from "antd"
import React, { useEffect } from "react"
import { useRequest } from "umi"
import moment from "moment"


interface Props {
    onChange?: (data: any) => void
    /** 默认值 */
    initialValues?: any
    /** 是否开启 广告账号 搜索 */
    isAccount?: boolean
    /** 是否开启 广告账户ID 搜索 */
    isAccountId?: boolean
    /** 是否开启 公司ID 搜索 */
    isCompanyId?: boolean
    /** 是否开启 CPID 搜索 */
    isCpId?: boolean
    /** 是否开启 cp名 搜索 */
    isCpName?: boolean
    /** 是否开启 CP方订单ID 搜索 */
    isCpOrderId?: boolean
    /** 是否开启 CP通知状态 搜索 */
    isCpStatus?: boolean
    /** 是否开启 订单创建日期 搜索 */
    isCreateDay?: boolean
    /** 是否开启 操作设备 搜索 */
    isDevice?: boolean
    /** 是否开启 注册游戏名 搜索 */
    isRechargeGameName?: boolean
    /** 是否开启 游戏名 搜索 */
    isGameName?: boolean
    /** 是否开启 游戏ID 搜索 */
    isGameId?: boolean
    /** 是否开启 游戏应用类型 搜索 */
    isGameType?: boolean
    /** 是否开启 游戏角色名 搜索 */
    isGameRoleName?: boolean
    /** 是否开启 游戏角色名ID 搜索 */
    isGameRoleId?: boolean
    /** 是否开启 是否首充 搜索 */
    isFirstRecharge?: boolean
    /** 是否开启 是否切量 搜索 */
    isSwitch?: boolean
    /** 是否开启 收款商户号 搜索 */
    isMerchantNo?: boolean
    /** 是否开启 商户订单ID 搜索 */
    isOrderId?: boolean
    /** 是否开启 支付状态 搜索 */
    isPayStatus?: boolean
    /** 是否开启 支付方式 搜索 */
    isPayWay?: boolean
    /** 是否开启 产品名称 搜索 */
    isProductName?: boolean
    /** 是否开启 注册渠道名 搜索 */
    isRegAgent?: boolean
    /** 是否开启 注册渠道ID 搜索 */
    isRegAgentId?: boolean
    /** 是否开启 投放渠道名 搜索 */
    isPutAgent?: boolean
    /** 是否开启 用户注册日期 搜索 */
    isRegDay?: boolean
    /** 是否开启 注册游戏名 搜索 */
    isRegGameName?: boolean
    /** 是否开启 注册游戏ID 搜索 */
    isRegGameId?: boolean
    /** 是否开启 投手名称 搜索 */
    isSysUserName?: boolean
    /** 是否开启 投手ID 搜索 */
    isSysUserId?: boolean
    /** 是否开启 用户名 搜索 */
    isUserName?: boolean
    /** 是否开启 用户ID 搜索 */
    isUserId?: boolean
    /** 是否开启 不同排行榜选择 搜索 */
    isSelectRanking?: boolean
    /** 是否开启 消耗日期 搜索 */
    isConsumeDay?: boolean
}
/**
 * 游戏数据系统 请求参数
 * @returns 
 */
const QueryForm: React.FC<Props> = (props) => {

    /**************************/
    const {
        onChange, initialValues, isAccount, isAccountId, isCompanyId, isCpId, isCpName, isCpOrderId, isCpStatus, isCreateDay, isDevice, isGameName, isRechargeGameName, isGameId, isGameRoleId, isGameRoleName, isFirstRecharge, isSwitch, isMerchantNo, isOrderId, isPayStatus, isPayWay, isProductName, isRegAgent, isRegAgentId, isPutAgent, isRegDay,
        isRegGameName, isRegGameId, isSysUserName, isSysUserId, isUserName, isUserId, isSelectRanking, isGameType, isConsumeDay
    } = props
    const [form] = Form.useForm()

    /**************************/

    useEffect(() => {
        if (isAccountId) {
            // 请求广告账号列表

        }
    }, [isAccountId])

    const onValuesChange = async () => {
        form.submit()
        let data = await form.validateFields()

        // 处理订单创建日期
        if (isCreateDay) {
            if (data?.createDay && data?.createDay?.length > 0) {
                data.createStartDay = moment(data?.createDay[0]).format('YYYY-MM-DD')
                data.createEndDay = moment(data?.createDay[1]).format('YYYY-MM-DD')
            } else {
                data.createStartDay = ''
                data.createEndDay = ''
            }
            delete data.createDay
        }
        // 处理 用户注册日期
        if (isRegDay) {
            if (data?.regDay && data?.regDay?.length > 0) {
                data.regStartDay = moment(data?.regDay[0]).format('YYYY-MM-DD')
                data.regEndDay = moment(data?.regDay[1]).format('YYYY-MM-DD')
            } else {
                data.regStartDay = ''
                data.regEndDay = ''
            }
            delete data.regDay
        }
        // 处理 消耗日期
        if (isConsumeDay) {
            if (data?.consumeDay && data?.consumeDay?.length > 0) {
                data.beginDay = moment(data?.consumeDay[0]).format('YYYY-MM-DD')
                data.endDay = moment(data?.consumeDay[1]).format('YYYY-MM-DD')
            } else {
                data.beginDay = ''
                data.endDay = ''
            }
            delete data.consumeDay
        }
        // 处理 不同排行榜 选择
        if (isSelectRanking) {
            switch (data?.dateType) {
                case 'all':
                    data.beginDay = ''
                    data.endDay = ''
                    break;
                case 'today':
                    data.beginDay = moment().format('YYYY-MM-DD')
                    data.endDay = moment().format('YYYY-MM-DD')
                    break
                case 'yesterday':
                    data.beginDay = moment().subtract(1, 'd').format('YYYY-MM-DD')
                    data.endDay = moment().subtract(1, 'd').format('YYYY-MM-DD')
                    break
                case '7days':
                    data.beginDay = moment().subtract(7, 'd').format('YYYY-MM-DD')
                    data.endDay = moment().format('YYYY-MM-DD')
                    break
                case '30days':
                    data.beginDay = moment().subtract(30, 'd').format('YYYY-MM-DD')
                    data.endDay = moment().format('YYYY-MM-DD')
                    break
            }
            delete data?.dateType
        }
        console.log('更新了字段---->', data);
        onChange && onChange(data)
    }

    const { data, loading, run } = useRequest(onValuesChange, {
        debounceInterval: 500,
        manual: true,
    });

    return <Form layout="inline" className='queryForm' initialValues={initialValues} name="basic" form={form} onValuesChange={run}>
        <Row gutter={[0, 10]}>
            {/* 不同排行榜选择 */}
            {isSelectRanking && <Col><Form.Item name='dateType'>
                <Radio.Group>
                    <Radio.Button value="all">总排行</Radio.Button>
                    <Radio.Button value="today">今日排行</Radio.Button>
                    <Radio.Button value="yesterday">昨日排行</Radio.Button>
                    <Radio.Button value="7days">7日排行</Radio.Button>
                    <Radio.Button value="30days">30日排行</Radio.Button>
                </Radio.Group>
            </Form.Item></Col>}
            {/* 广告账户名称 */}
            {isAccount && <Col><Form.Item name='account'>
                <Input placeholder="请输入广告账号" allowClear />
            </Form.Item></Col>}
            {/* 广告账号ID */}
            {isAccountId && <Col><Form.Item name='accountId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择广告账号'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>账户001</Select.Option>
                    <Select.Option value={'2'}>账户002</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 公司ID */}
            {isCompanyId && <Col><Form.Item name='companyId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择公司'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>公司001</Select.Option>
                    <Select.Option value={'2'}>公司002</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* cp名 */}
            {isCpName && <Col><Form.Item name='cpName'>
                <Input placeholder="请输入CP名称" allowClear />
            </Form.Item></Col>}
            {/* CPID */}
            {isCpId && <Col><Form.Item name='cpId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择CP'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>CP001</Select.Option>
                    <Select.Option value={'2'}>CP002</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* CP方订单ID */}
            {isCpOrderId && <Col><Form.Item name='cpOrderId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择CP方订单'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>CP方订单001</Select.Option>
                    <Select.Option value={'2'}>CP方订单002</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* CP通知状态 */}
            {isCpStatus && <Col><Form.Item name='cpStatus'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择CP通知状态'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>待处理</Select.Option>
                    <Select.Option value={'2'}>成功</Select.Option>
                    <Select.Option value={'3'}>失败</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 订单创建日期搜索 */}
            {isCreateDay && <Col><Form.Item name='createDay'>
                <DatePicker.RangePicker placeholder={['订单创建开始日期', '订单创建结束日期']} />
            </Form.Item></Col>}
            {/* 操作设备 */}
            {isDevice && <Col><Form.Item name='device'>
                <Input placeholder="请输入操作设备" allowClear />
            </Form.Item></Col>}
            {/* 游戏名 */}
            {isRechargeGameName && <Col><Form.Item name='rechargeGameName'>
                <Input placeholder="请输入游戏名" allowClear />
            </Form.Item></Col>}
            {/* 游戏名 */}
            {isGameName && <Col><Form.Item name='gameName'>
                <Input placeholder="请输入游戏名" allowClear />
            </Form.Item></Col>}
            {/* 游戏ID搜索 */}
            {isGameId && <Col><Form.Item name='gameId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择游戏'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>游戏1</Select.Option>
                    <Select.Option value={'2'}>游戏2</Select.Option>
                    <Select.Option value={'3'}>游戏3</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 游戏应用类型搜索 */}
            {isGameType && <Col><Form.Item name='gameType'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择游戏应用类型'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>游戏应用类型1</Select.Option>
                    <Select.Option value={'2'}>游戏应用类型2</Select.Option>
                    <Select.Option value={'3'}>游戏应用类型3</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 游戏角色名 */}
            {isGameRoleName && <Col><Form.Item name='gameRoleName'>
                <Input placeholder="请输入游戏角色名" allowClear />
            </Form.Item></Col>}
            {/* 游戏角色名id搜索 */}
            {isGameRoleId && <Col><Form.Item name='gameRoleId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择游戏角色名'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>游戏角色名1</Select.Option>
                    <Select.Option value={'2'}>游戏角色名2</Select.Option>
                    <Select.Option value={'3'}>游戏角色名3</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 是否首充 */}
            {isFirstRecharge && <Col><Form.Item name='isFirstRecharge'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择是否首充'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'0'}>否</Select.Option>
                    <Select.Option value={'1'}>是</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 是否切量 */}
            {isSwitch && <Col><Form.Item name='isSwitch'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择是否切量'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'0'}>否</Select.Option>
                    <Select.Option value={'1'}>是</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 收款商户号 */}
            {isMerchantNo && <Col><Form.Item name='merchantNo'>
                <Input placeholder="请输入收款商户号" allowClear />
            </Form.Item></Col>}
            {/* 收款商户号 */}
            {isOrderId && <Col><Form.Item name='orderId'>
                <Input placeholder="请输入商户订单ID" allowClear />
            </Form.Item></Col>}
            {/* 支付状态 */}
            {isPayStatus && <Col><Form.Item name='payStatus'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择支付状态'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={1}>待处理</Select.Option>
                    <Select.Option value={2}>成功</Select.Option>
                    <Select.Option value={3}>失败</Select.Option>
                </Select>
            </Form.Item></Col>}
            {/* 支付方式 */}
            {isPayWay && <Col><Form.Item name='payWay'>
                <Input placeholder="请输入支付方式" allowClear />
            </Form.Item></Col>}
            {/* 产品名称 */}
            {isProductName && <Col><Form.Item name='productName'>
                <Input placeholder="请输入产品名称" allowClear />
            </Form.Item></Col>}

            {/* 注册渠道名 */}
            {isRegAgent && <Col><Form.Item name='regAgent'>
                <Input placeholder="请输入注册渠道名" allowClear />
            </Form.Item></Col>}
            {/* 注册渠道id */}
            {isRegAgentId && <Col><Form.Item name='regAgentId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择注册渠道'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>注册渠道001</Select.Option>
                    <Select.Option value={'2'}>注册渠道002</Select.Option>
                    <Select.Option value={'3'}>注册渠道003</Select.Option>
                </Select>
            </Form.Item></Col>}

            
            {/* 投放渠道名 */}
            {isPutAgent && <Col><Form.Item name='putAgent'>
                <Input placeholder="请输入投放渠道名" allowClear />
            </Form.Item></Col>}

            {/* 用户注册日期搜索 */}
            {isRegDay && <Col><Form.Item name='regDay'>
                <DatePicker.RangePicker placeholder={['用户注册开始日期', '用户注册结束日期']} />
            </Form.Item></Col>}

            {/* 注册游戏名 */}
            {isRegGameName && <Col><Form.Item name='regGameName'>
                <Input placeholder="请输入注册游戏名" allowClear />
            </Form.Item></Col>}
            {/* 注册游戏id */}
            {isRegGameId && <Col><Form.Item name='regGameId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择注册游戏'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>注册游戏001</Select.Option>
                    <Select.Option value={'2'}>注册游戏002</Select.Option>
                    <Select.Option value={'3'}>注册游戏003</Select.Option>
                </Select>
            </Form.Item></Col>}

            {/* 投手名 */}
            {isSysUserName && <Col><Form.Item name='sysUserName'>
                <Input placeholder="请输入投手名" allowClear />
            </Form.Item></Col>}
            {/* 投手ID */}
            {isSysUserId && <Col><Form.Item name='sysUserId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择投手'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>投手001</Select.Option>
                    <Select.Option value={'2'}>投手002</Select.Option>
                    <Select.Option value={'3'}>投手003</Select.Option>
                </Select>
            </Form.Item></Col>}

            {/* 用户名 */}
            {isUserName && <Col><Form.Item name='userName'>
                <Input placeholder="请输入用户名" allowClear />
            </Form.Item></Col>}
            {/* 用户id */}
            {isUserId && <Col><Form.Item name='userId'>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 150 }}
                    allowClear
                    placeholder={'请选择用户'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={'1'}>用户001</Select.Option>
                    <Select.Option value={'2'}>用户002</Select.Option>
                    <Select.Option value={'3'}>用户003</Select.Option>
                </Select>
            </Form.Item></Col>}


            {/* 消耗日期 搜索 */}
            {isConsumeDay && <Col><Form.Item name='consumeDay'>
                <DatePicker.RangePicker placeholder={['消耗开始日期', '消耗结束日期']} />
            </Form.Item></Col>}
        </Row>
    </Form>
}


export default React.memo(QueryForm)