import CustomListModel from '@/components/CustomList'
import Tables from '@/components/Tables'
import { FullscreenExitOutlined, FullscreenOutlined, RedoOutlined, SearchOutlined, SettingOutlined } from '@ant-design/icons'
import { useFullscreen } from 'ahooks'
import { Button, Card, Col, Row, Space, Tooltip, } from 'antd'
import React, { useEffect, useRef, useState, useCallback } from 'react'
import style from './index.less'
import moment from 'moment'

interface Prosp {
    isZj?: boolean,//是否查总计
    tableTotal?: { [key: string]: string },//是个开启总计
    scroll?: { x?: number, y?: number },//开启行滑动并设置容器最大宽度
    title?: string,//tabel的标题
    tooltip?: JSX.Element,//是否在标题后加问号展示说明
    dataSource: any[],//table的数据
    expandedRowRender?: (data: any) => JSX.Element,
    className?: string,//自定义class
    isdownload?: boolean,
    leftChild?: JSX.Element,
    config?: any,
    configName?: any,
    page?: number,
    pageSize?: number,
    size?: 'small' | 'middle' | 'large',
    total?: number,
    onChange?: (props: {
        pagination?: { current?: number, pageSize?: number, gzh?: string },
        filters?: any,
        sortData?: {
            column: { dataIndex: string },
            order?: "ascend" | "descend"
        }
    }) => void,
    ajax?: any,//接口刷新
    fixed?: {
        left: number,
        right: number
    },
    summary?: ((data: readonly any[]) => React.ReactNode)
}

function TableData(props: Prosp) {

    /*************************/
    const { isZj, scroll, title, dataSource, expandedRowRender, className, leftChild, page = undefined, pageSize = undefined, size = 'small', total = 0, onChange, config, configName, ajax, fixed = { left: 0, right: 1 }, summary } = props
    const [visible, setVisible] = useState<boolean>(false)
    const [isFullscreen, setIsFullscreen] = useState<boolean>(true)
    const [oldSelectData, setoldSelectData] = useState<any[]>([])
    const [oldFixed, setoldFixed] = useState<any>({ left: '0', right: '0' })
    const [newColumns, setNewColumns] = useState<any[]>([])
    const [timer, setTimer] = useState<string>(moment().format('HH:mm:ss'))
    const [selectData, setSelectData] = useState<{ selectData: any[], fixed: { left: number, right: number } }>({ selectData: [], fixed: { left: fixed.left, right: fixed.right } })
    const ref = useRef(null)
    const [isFull, { toggleFull }] = useFullscreen(ref);
    const oldName = useRef(null)
    const version = '1.0.0'
    /*************************/

    /**重组选中的字段 */
    useEffect(() => {
        let oldConfigName = oldName.current || ''
        if (configName) {
            const defSelectData = localStorage.getItem(`myAdMonitorConfig${version}_` + configName)
            const defFixed = localStorage.getItem(`myAdMonitorConfigFixed${version}_` + configName)
            let newArr: any = [], fixedData: { left: number, right: number } = selectData.fixed
            const newConfig = config?.map((item: { data: any }) => item.data)?.flat()
            if (defSelectData) {
                newArr = JSON.parse(defSelectData)
            }
            if (defSelectData && (selectData?.selectData?.length === 0 || configName !== oldConfigName)) {//首次查找个人配置是否存在，并且selectData为空，存在用个人配置设置selectData
                console.log('首次使用个人配置赋值')
                let newDefSelectData = JSON.parse(defSelectData)
                newDefSelectData = newDefSelectData.filter((item: any) => !!item && newConfig.some((c: { dataIndex: any }) => c.dataIndex === item.dataIndex))//去除空项
                setSelectData(() => ({ selectData: newDefSelectData, fixed: defFixed ? JSON.parse(defFixed) : { left: 0, right: 0 } }))
                fixedData = defFixed ? JSON.parse(defFixed) : { left: 0, right: 0 }
                newArr = newDefSelectData
            }
            if (!defSelectData && (selectData?.selectData?.length === 0 || configName !== oldConfigName)) {//首次查找个人配置是否存在，并且selectData为空，不存在默认配置设置selectData
                let newSelectData: any[] = []
                config?.forEach((item: { data: { default: any }[] }) => {
                    item?.data?.forEach((d: { default: any }) => {
                        if (d.default) {
                            newSelectData[d.default - 1] = d
                        }
                    })
                })
                console.log('首次使用默认配置赋值')
                setSelectData(() => ({ ...selectData, selectData: newSelectData }))
                newArr = newSelectData
            }
            if ((JSON.stringify(oldSelectData) !== JSON.stringify(selectData?.selectData)) || (JSON.stringify(selectData.fixed) !== JSON.stringify(oldFixed))) {
                console.log('设置配置改变重新赋值')
                setoldSelectData(() => selectData.selectData)
                setoldFixed(() => selectData.fixed)
                if (newArr.length > 0) {
                    setNewColumns(newArr.map((item: any, index: number) => {
                        item = newConfig.find((c: { dataIndex: any }) => c.dataIndex === item.dataIndex)
                        if (index < Number(fixedData.left)) {//设置左悬浮
                            item['fixed'] = 'left'
                        } else if (index > (newArr?.length - Number(fixedData.right) - 1)) {//设置右悬浮
                            item['fixed'] = 'right'
                        } else {
                            item['fixed'] = false
                        }
                        delete item?.label
                        delete item?.default
                        return item
                    }))
                }
            }
        }
        if (configName !== oldConfigName) {
            oldName.current = configName
        }
    }, [selectData, oldSelectData, dataSource, oldFixed, configName, config, timer])

    //拖动宽度设置设置保存
    const handelResize = useCallback((columns: any) => {
        if (configName) {
            let newSelectData = selectData?.selectData?.map((item, index) => {
                item['width'] = columns[index]['width']
                return item
            })
            localStorage.setItem(`myAdMonitorConfig${version}_` + configName, JSON.stringify(newSelectData))
        }
    }, [configName, selectData])
    
    const header = <Col span={24}>
        <Row gutter={[0, 10]} align='bottom'>
            <Col flex='1 1 150px'>
                {isFullscreen && leftChild}
            </Col>
            <Col flex='0 1 150px'>
                {/*紧凑*/}
                <Space style={{ float: 'right', marginBottom: 4 }}>
                    <Button size='small' type='text' style={{ color: '#F56C6C' }} onClick={() => { setIsFullscreen(!isFullscreen) }}>
                        <Tooltip title={isFullscreen ? '隐藏搜索' : '显示搜索'}><SearchOutlined /></Tooltip>
                    </Button>
                    {ajax && <Button
                        size='small'
                        type='text'
                        style={{ color: '#67C23A' }}
                        onClick={() => {
                            ajax.refresh()
                        }}>
                        {/* <span style={{ fontSize: 10, color: '#999' }}>刷新时间:{ajax?.data?.reqTime}</span> */}
                        <Tooltip title='刷新'><RedoOutlined /></Tooltip>
                    </Button>}
                    <Button
                        size='small'
                        type='text'
                        style={{ color: '#E6A23C' }}
                        onClick={() => {
                            setVisible(true)
                        }}>
                        <Tooltip title='设置'><SettingOutlined /></Tooltip>
                    </Button>
                    <Button
                        type='text'
                        size='small'
                        style={{ color: '#409EFF' }}
                        onClick={toggleFull}>
                        {<Tooltip title={!isFull ? '全屏' : '退出全屏'}>{!isFull ? <FullscreenOutlined /> : <FullscreenExitOutlined />}</Tooltip>}
                    </Button>
                    {visible && <CustomListModel sysFixed={fixed} version={version} config={config} configName={configName} visible={visible} onClose={() => { setVisible(false) }} onChange={(arr: any) => { setTimer(moment().format('HH:mm:ss')); if (arr) { setSelectData({ selectData: [], fixed: { left: fixed.left, right: fixed.right } }) } else { setSelectData({ selectData: [], fixed: { left: fixed.left, right: fixed.right } }) } }} columns={newColumns} />}
                </Space>
            </Col>
        </Row>
    </Col>
    const content = <Row gutter={[0, 20]} ref={ref} style={isFull ? { background: '#fff' } : {}}>
        {/**table */}
        <Col span={24}>
            <Card
                hoverable
                title={<div style={{ textAlign: 'center', color: '#1890ff', fontWeight: 'bold' }}>{title}</div>}
                headStyle={{ textAlign: 'left' }}
            >
                <Row gutter={[0, 16]}>
                    {header}
                    <Tab {...{ size, newColumns, handelResize, className, isZj, scroll, isFull, page, pageSize, dataSource, onChange, expandedRowRender, total, ajax, summary }} />
                </Row>
            </Card>
        </Col>
    </Row >
    return <>
        {content}
    </>
}

/**表格 */
const Tab = React.memo((props: any) => {
    const { size, newColumns, className, handelResize, scroll, isFull, page, pageSize, dataSource, onChange, expandedRowRender, total, ajax, summary } = props

    return < Col span={24} >
        <div className={`${style[size]} ${className ? style[className] : ''} `}>
            <Tables
                className={`all_table ${className ? className : ''}`}
                bordered
                sortDirections={['ascend', 'descend', null]}
                current={page}
                pageSize={pageSize}
                columns={newColumns}
                dataSource={dataSource}
                scroll={scroll ? isFull ? { ...scroll, y: document.body.clientHeight - 300 } : scroll : {}}
                onChange={(pagination: any, filters: any, sorter: any) => onChange && onChange({ pagination, filters, sortData: sorter })}
                rowClassName={(record: { color: string }) => style[record['color']]}
                expandedRowRender={expandedRowRender ? expandedRowRender : undefined}
                size={size}
                total={total}
                loading={ajax?.loading}
                defaultPageSize={20}
                handelResize={((columns: any) => handelResize(columns))}
                summary={summary}
            />
        </div>
    </Col >
})
export default React.memo(TableData)