import QueryForm from "@/components/QueryForm"
import { useAjax } from "@/Hook/useAjax"
import { getOrderListApi, OrderListType } from "@/services/gameData/order"
import { Statistic, Table } from "antd"
import React, { useEffect, useState } from "react"
import TableData from "../components/TableData"
import columns12 from "./tableConfig"



const Order: React.FC = () => {

    /***************************/
    const [queryForm, setQueryForm] = useState<OrderListType>({ pageNum: 1, pageSize: 20 })
    const getOrderList = useAjax((params) => getOrderListApi(params))
    /***************************/

    useEffect(() => {
        getOrderList.run(queryForm)
    }, [queryForm])

    return <div>

        <TableData
            leftChild={<QueryForm
                onChange={(data: any) => setQueryForm({ ...queryForm, pageNum: 1, ...data })}
                isAccount
                isAccountId
                isCompanyId
                isCpId
                isCpName
                isCpOrderId
                isCpStatus
                isCreateDay
                isDevice
                isRechargeGameName 
                isGameId
                isGameRoleId
                isGameRoleName
                isFirstRecharge
                isSwitch
                isMerchantNo
                isOrderId
                isPayStatus
                isPayWay
                isProductName
                isRegAgent
                isRegAgentId
                isRegDay
                isRegGameName
                isRegGameId
                isSysUserName
                isSysUserId
                isUserName
                isUserId
            />}
            scroll={{ x: 1000, y: 600 }}
            ajax={getOrderList}
            fixed={{ left: 3, right: 0 }}
            dataSource={getOrderList?.data?.records}
            total={getOrderList?.data?.total}
            page={queryForm.pageNum}
            pageSize={queryForm.pageSize}
            title='订单明细'
            onChange={(props: any) => {
                console.log('props--->', props)
                setQueryForm({ ...queryForm, pageNum: props?.pagination?.current || 1, pageSize: props?.pagination?.pageSize || 20 })
            }}
            config={columns12()}
            configName={'订单明细'}
            summary={() => {
                let defSelectData = localStorage.getItem(`myAdMonitorConfig1.0.0_订单明细`)
                let newDefSelectData: any[] = []
                if (defSelectData) {
                    newDefSelectData = JSON.parse(defSelectData)
                } else {
                    newDefSelectData = columns12()[0]?.data
                }
                return <Table.Summary fixed={'top'}>
                    <Table.Summary.Row>
                        {newDefSelectData?.map((item: { dataIndex: string }, index: number) => {
                            if (item.dataIndex === 'amount') {
                                return <Table.Summary.Cell index={index} align='center' key={index}><Statistic valueStyle={{ color: 'red', fontWeight: 600 }} value={getOrderList?.data?.totalData?.totalAmount || 0} precision={2}/></Table.Summary.Cell>
                            } else if (item.dataIndex === 'realAmount') {
                                return <Table.Summary.Cell index={index} align='center' key={index}><Statistic valueStyle={{ color: 'red', fontWeight: 600 }} value={getOrderList?.data?.totalData?.totalRealAmount || 0} precision={2}/></Table.Summary.Cell>
                            } else if (index === 0) {
                                return <Table.Summary.Cell index={index} align='center' key={index}><span style={{ fontSize: 16, fontWeight: 'bold' }}>汇总</span></Table.Summary.Cell>
                            }
                            return <Table.Summary.Cell index={index} align='center' key={index}><span>--</span></Table.Summary.Cell>
                        })}
                    </Table.Summary.Row>
                </Table.Summary>
            }}
        />
    </div>
}

export default Order