import { useAjax } from "@/Hook/useAjax"
import { GameRechargeListType, getRechargeGameListApi } from "@/services/gameData/rankingList"
import { Radio, Space } from "antd"
import React, { useEffect, useState } from "react"
import TableData from "../../components/TableData"
import columns12 from "./tableConfig"
import moment from "moment"


const Game: React.FC = () => {

    /************************/
    const [dateType, setDateType] = useState<string>('all')
    const [queryForm, setQueryForm] = useState<GameRechargeListType>({ pageNum: 1, pageSize: 20 })
    const getRechargeGameList = useAjax((params) => getRechargeGameListApi(params))
    /************************/

    useEffect(() => {
        getRechargeGameList.run(queryForm)
    }, [queryForm])

    useEffect(() => {
        let newQueryForm = JSON.parse(JSON.stringify(queryForm))
        switch(dateType) {
            case 'all':
                delete newQueryForm?.beginDay
                delete newQueryForm?.endDay
                break;
            case 'today':
                newQueryForm.beginDay = moment().format('YYYY-MM-DD')
                newQueryForm.endDay = moment().format('YYYY-MM-DD')
                break
            case 'yesterday':
                newQueryForm.beginDay = moment().subtract(1, 'd').format('YYYY-MM-DD')
                newQueryForm.endDay = moment().subtract(1, 'd').format('YYYY-MM-DD')
                break
            case '7days':
                newQueryForm.beginDay = moment().subtract(7, 'd').format('YYYY-MM-DD')
                newQueryForm.endDay = moment().format('YYYY-MM-DD')
                break
            case '30days':
                newQueryForm.beginDay = moment().subtract(30, 'd').format('YYYY-MM-DD')
                newQueryForm.endDay = moment().format('YYYY-MM-DD')
                break
        }
        setQueryForm(newQueryForm)
    }, [dateType])

    return <div>
        <TableData
            leftChild={<Space>
                <Radio.Group value={dateType} onChange={(e) => setDateType(e.target.value)}>
                    <Radio.Button value="all">总排行</Radio.Button>
                    <Radio.Button value="today">今日排行</Radio.Button>
                    <Radio.Button value="yesterday">昨日排行</Radio.Button>
                    <Radio.Button value="7days">7日排行</Radio.Button>
                    <Radio.Button value="30days">30日排行</Radio.Button>
                </Radio.Group>
            </Space>}
            scroll={{ x: 1000, y: 600 }}
            ajax={null}
            fixed={{ left: 1, right: 0 }}
            dataSource={[]}
            title='游戏充值排行榜'
            onChange={(props: any) => {
                console.log('props--->', props)
            }}
            config={columns12()}
            configName={'游戏充值排行榜'}
        />
    </div>
}

export default Game